==> ksteak-0.4.0.tar.gz: ksteak-0.4.0/ksteak/options.h <==
/***************************************************************************
                          optionsdialog.h  -  description
                             -------------------
    begin                : Fri Mar 16 2001
    copyright            : (C) 2001 by Michael Heidecke
    email                : heidecke@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef OPTIONS_H
#define OPTIONS_H

#include <kdialogbase.h>
#include <kcolorbutton.h>
#include <qframe.h>
#include "ksteak.h"
#include <kfontdialog.h>

/**
  *@author Michael Heidecke
  */

class OptionsDialog : public KDialogBase 
{
  Q_OBJECT
public:
  OptionsDialog( KSteak *parent = 0, const char *name = 0, bool modal = FALSE, WFlags fl = 0 );
  // ~OptionsDialog();
public slots:
    virtual void slotApply();
    virtual void slotOk();

private:
 QFrame *f, *f2; 
 KColorButton *Button1, *Button2, *Button3;
 KSteak *par;
 KFontChooser *Fontchooser;
};

#endif

==> ksteak-0.4.3.tar.gz: ksteak-0.4.3/ksteak/options.h <==
/***************************************************************************
                          optionsdialog.h  -  description
                             -------------------
    begin                : Fri Mar 16 2001
    copyright            : (C) 2001 by Michael Heidecke
    email                : heidecke@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef OPTIONS_H
#define OPTIONS_H

#include "ksteak.h"
#include <qframe.h>
#include <kdialogbase.h>
#include <kcolorbutton.h>
#include <kfontdialog.h>
#include <kkeydialog.h>

/**
  *@author Michael Heidecke
  */

class OptionsDialog : public KDialogBase 
{
  Q_OBJECT
public:
  OptionsDialog( KSteak *parent = 0, const char *name = 0, bool modal = FALSE, WFlags fl = 0 );
  // ~OptionsDialog();
public slots:
    virtual void slotApply();
    virtual void slotOk();

private:
 QFrame *f, *f2, *f3;
 KColorButton *Button1, *Button2, *Button3;
 KSteak *par;
 KFontChooser *Fontchooser;
 KKeyChooser *Keychooser;
 KKeyEntryMap *mymap;
};

#endif
